@@ -35,22 +35,36 @@ pub struct LintConfig {
     /// The name of the linter, conventionally capitals and numbers, no spaces,
     /// dashes, or underscores
     ///
-    ///    e.g. 'FLAKE8' or 'CLANGFORMAT'
-    code: String,
+    /// # Examples
+    /// - `'FLAKE8'`
+    /// - `'CLANGFORMAT'`
+    pub code: String,
 
     /// A list of UNIX-style glob patterns. Paths matching any of these patterns
     /// will be linted. Patterns should be specified relative to the location
     /// of the config file.
     ///
-    ///   e.g. `['torch/csrc/**/*.cpp', 'test/foo.py']`
-    include_patterns: Vec<String>,
+    /// # Examples
+    /// - Matching against everything:
+    /// ```toml
+    /// include_patterns = ['**']
+    /// ```
+    /// - Matching against a specific file extension:
+    /// ```toml
+    /// include_patterns = ['include/**/*.h', 'src/**/*.cpp']
+    /// ```
+    /// - Match a specific file:
+    /// ```toml
+    /// include_patterns = ['include/caffe2/caffe2_operators.h', 'torch/csrc/jit/script_type.h']
+    /// ```
+    pub include_patterns: Vec<String>,
 
     /// A list of UNIX-style glob patterns. Paths matching any of these patterns
     /// will be never be linted, even if they match an include pattern.
     ///
-    ///   e.g. `['torch/csrc/**/*.cpp', 'test/foo.py']`
+    /// For examples, see: [`LintConfig::include_patterns`]
     #[serde(skip_serializing_if = "Option::is_none")]
-    exclude_patterns: Option<Vec<String>>,
+    pub exclude_patterns: Option<Vec<String>>,
 
     /// A list of arguments describing how the linter will be called. lintrunner
     /// will create a subprocess and invoke this command.
@@ -62,8 +76,12 @@ pub struct LintConfig {
     /// The paths in `{{PATHSFILE}}` will always be canoncalized (e.g. they are
     /// absolute paths with symlinks resolved).
     ///
-    ///   e.g. `['python3', 'my_linter.py', '@{{PATHSFILE}}']`
-    command: Vec<String>,
+    /// # Examples
+    /// - Calling a Python script:
+    /// ```toml
+    /// command = ['python3', 'my_linter.py', -- '@{{PATHSFILE}}']
+    /// ```
+    pub command: Vec<String>,
 
     /// A list of arguments describing how to set up the right dependencies for
     /// this linter. This command will be run when `lintrunner init` is called.
@@ -73,7 +91,12 @@ pub struct LintConfig {
     ///
     /// If `{{DRYRUN}}` is set, this command is expected to not make any changes
     /// to the user's environment, instead it should only print what it will do.
-    init_command: Option<Vec<String>>,
+    ///
+    /// # Examples
+    /// - Calling a Python script:
+    /// ```toml
+    /// command = ['python3', 'my_linter_init.py', '--dry-run={{DRYRUN}}']
+    pub init_command: Option<Vec<String>>,
 }
 
 /// Given options specified by the user, return a list of linters to run.
